==> nextcloud-app-bookmarks-1%3A15.0.3-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/hr.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Knjižne oznake",
    "You bookmarked \"%s\"" : "Dodali ste knjižnu oznaku na „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s je dodao knjižnu oznaku na „%2$s“",
    "Someone bookmarked \"%s\"" : "Netko je dodao knjižnu oznaku na „%s“",
    "You deleted \"%s\"" : "Izbrisali ste „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s je izbrisao „%2$s“",
    "Someone deleted \"%s\"" : "Netko je izbrisao „%s“",
    "You created folder \"%s\"" : "Stvorili ste mapu „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s je stvorio mapu „%2$s“",
    "Someone created folder \"%s\"" : "Netko je stvorio mapu „%s“",
    "You moved folder \"%s\"" : "Premjestili ste mapu „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s je premjestio mapu „%2$s“",
    "Someone moved folder \"%s\"" : "Netko je premjestio mapu „%s“",
    "You deleted folder \"%s\"" : "Izbrisali ste mapu „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s je izbrisao mapu „%2$s“",
    "Someone deleted folder \"%s\"" : "Netko je izbrisao mapu „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Dijelite mapu „%1$s“ s „%2$s“",
    "You shared folder \"%s\" with someone" : "Dijelite mapu „%s“ s nekim",
    "%1$s shared folder \"%2$s\" with you" : "%1$s dijeli mapu „%2$s“ s vama",
    "Someone shared folder \"%s\" with you" : "Netko s vama dijeli mapu „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Više ne dijelite mapu „%1$s“ s %2$s",
    "You unshared folder \"%s\" with someone" : "Više ne dijelite mapu „%s“ s nekim",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s više ne dijeli mapu „%2$s“ s vama",
    "Someone unshared folder \"%s\" with you" : "Netko više ne dijeli mapu „%s“ s vama",
    "No file provided for import" : "Nije navedena datoteka za uvoz",
    "Bookmarks shared by %s" : "Knjižne oznake dijeljene s %s",
    "Frequent bookmarks" : "Česte knjižne oznake",
    "Recent bookmarks" : "Nedavne knjižne oznake",
    "Bookmark" : "Dodaj knjižnu oznaku",
    "Bookmark deleted" : "Knjižna oznaka je izbrisana",
    "Bookmark created" : "Knjižna oznaka je stvorena",
    "Bookmark moved" : "Knjižna oznaka je premještena",
    "Bookmark updated" : "Knjižna oznaka je ažurirana",
    "Create bookmark" : "Stvori knjižnu oznaku",
    "Takes a link and adds it to your collection of bookmarks." : "Dodaje poveznicu u zbirku knjižnih oznaka.",
    "Enter new title" : "Unesi novi naslov",
    "Select bookmark" : "Odaberi knjižnu oznaku",
    "Details" : "Pojedinosti",
    "Rename" : "Preimenuj",
    "Copy link" : "Kopiraj poveznicu",
    "Move" : "Premjesti",
    "Add to folders" : "Dodaj u mape",
    "Do you really want to delete this bookmark?" : "Želite li zaista izbrisati ovu knjižnu oznaku?",
    "Link copied to clipboard" : "Poveznica je kopirana u međuspremnik",
    "Content pending" : "Sadržaj na čekanju",
    "This content is being downloaded for offline use. Please check back later." : "Ovaj se sadržaj preuzima radi vanmrežne uporabe. Provjerite kasnije.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke na internetu, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
    "Open all selected" : "Otvori sve odabrano",
    "Move selection" : "Premjesti odabir",
    "Edit tags of selection" : "Uredi oznake odabira",
    "Delete selection" : "Izbriši odabir",
    "Select all" : "Odaberi sve",
    "Cancel selection" : "Poništi odabir",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Odabrane mape {folders} i knjižne oznake {bookmarks}",
    "Do you really want to delete these items?" : "Želite li zaista izbrisati ove stavke?",
    "Go back" : "Natrag",
    "Share folder" : "Dijeli mapu",
    "Select one or more tags" : "Odaberite jednu ili više oznaka",
    "New" : "Novo",
    "New bookmark" : "Nova knjižna oznaka",
    "New folder" : "Nova mapa",
    "Change to grid view" : "Promijeni u prikaz rešetke",
    "Change to list view" : "Promijeni u prikaz popisa",
    "Copy RSS Feed of current view" : "Kopiraj sažetak događaja RSS trenutnog prikaza",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Sažetak događaja RSS zahtijeva autentifikaciju s pomoću Nextcloudovih vjerodajnica",
    "Search" : "Traži",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "Sort by created date" : "Razvrstaj prema datumu stvaranja",
    "Sort by last modified" : "Razvrstaj prema posljednjoj izmjeni",
    "Sort by title" : "Razvrstaj prema naslovu",
    "Sort by click count" : "Razvrstaj prema broju klikova",
    "Sort by manual order" : "Razvrstaj prema ručno odabranom redoslijedu",
    "RSS feed copied" : "Sažetak događaja RSS kopiran",
    "Enter a link" : "Unesite poveznicu",
    "Enter a title" : "Unesite naslov",
    "No bookmarks found" : "Nije pronađena nijedna knjižna oznaka",
    "{folders} folders and {bookmarks} bookmarks" : "Mape {folders} i knjižne oznake {bookmarks}",
    "Add a bookmark" : "Dodaj knjižnu oznaku",
    "Import bookmarks" : "Uvezi knjižne oznake",
    "Sync with your browser" : "Sinkronizirajte s preglednikom",
    "Select folder" : "Odaberi mapu",
    "Enter folder title" : "Unesite naslov mape",
    "Shared by {user}" : "Dijeli {user}",
    "Rename folder" : "Preimenuj mapu",
    "Move folder" : "Premjesti mapu",
    "Choose folder" : "Odaberi mapu",
    "Submit" : "Šalji",
    "Cancel" : "Odustani",
    "Deleting bookmarks" : "Brisanje knjižnih oznaka",
    "Deleting selection" : "Brisanje odabira",
    "Importing bookmarks" : "Uvoz knjižnih oznaka",
    "Moving selection" : "Premještanje odabira",
    "Adding selection to folders" : "Dodavanje odabira u mape",
    "All bookmarks" : "Sve knjižne oznake",
    "Recent" : "Nedavni",
    "Shared with you" : "Podijeljeno s vama",
    "Files" : "Datoteke",
    "Broken links" : "Prekinute poveznice",
    "New tag" : "Nova oznaka",
    "Search tags" : "Oznake pretraživanja",
    "Delete" : "Izbriši",
    "Untagged" : "Uklonjene oznake",
    "{used} bookmarks of {available} available" : "{used} knjižnih oznaka od {available} dostupnih",
    "No bookmarked files" : "Nema datoteka označenih kao knjižne oznake",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
    "No bookmarks here" : "Ovdje nema knjižnih oznaka",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Unesite put do mape u aplikaciji Files u kojoj trebaju biti pohranjene datoteke označene kao knjižne oznake.",
    "Client apps" : "Korisnička aplikacija",
    "Also check out the collection of client apps that integrate with this app: " : "Također pregledajte zbirku klijentskih aplikacija koje se mogu integrirati s ovom aplikacijom:",
    "Install web app" : "Instaliraj web aplikaciju",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Ovu aplikaciju možete instalirati na početni zaslon uređaja kako biste mogli brzo pristupiti knjižnim oznakama na telefonu. Ako vam se aplikacija ne sviđa, lako je možete ukloniti s početnog zaslona.",
    "Install on home screen" : "Instaliraj na početni zaslon",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Odvucite na knjižne oznake u svom pregledniku i kliknite kako biste brzo spremili mrežno mjesto u knjižne oznake.",
    "Add to {instanceName}" : "Dodaj u {instanceName}",
    "Need help?" : "Treba li vam pomoć?",
    "Archive path" : "Put arhive",
    "Please select \"Add to home screen\" in your browser menu" : "Odaberite „Dodaj na početni zaslon“ u izborniku preglednika",
    "Title" : "Naslov",
    "Link" : "Poveznica",
    "Untitled folder" : "Mapa bez naslova",
    "Root folder" : "Korijenska mapa",
    "Tags" : "Oznake",
    "Select tags and create new ones" : "Odaberite oznake i stvorite nove",
    "Notes" : "Bilješke",
    "Notes for this bookmark …" : "Bilješke za ovu knjižnu oznaku…",
    "Archived file" : "Arhivirana datoteka",
    "Download file" : "Preuzmi datoteku",
    "Open file location" : "Otvori lokaciju datoteke",
    "Created {time} ago" : "Stvoreno prije {time}",
    "Created on {date}" : "Stvoreno {date}",
    "Owner" : "Vlasnik",
    "Sharing" : "Dijeljenje",
    "Select a user or group" : "Odaberite korisnika ili grupu",
    "Share link" : "Dijeli poveznicu",
    "Reading allowed" : "Čitanje dopušteno",
    "Copy RSS feed" : "Kopiraj sažetak događaja RSS",
    "Delete link" : "Izbriši poveznicu",
    "Create public link" : "Stvori javnu poveznicu",
    "Resharing allowed" : "Ponovno dijeljenje dopušteno",
    "Editing allowed" : "Uređivanje dopušteno",
    "Allow editing" : "Dopusti uređivanje",
    "Allow resharing" : "Dopusti ponovno dijeljenje",
    "Remove share" : "Ukloni dijeljenje",
    "Link copied" : "Poveznica je kopirana",
    "Privacy" : "Privatnost",
    "Enable accessing and collecting information from the web pages you add" : "Omogući pristup i prikupljanje informacija s dodanih mrežnih mjesta",
    "Performance" : "Učinkovitost",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Kod instalacija s većim brojem korisnika može biti korisno ograničiti broj knjižnih oznaka po računu.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Najveći dopušteni broj knjižnih oznaka po računu. (0 znači da nema ograničenja; zadano je bez ograničenja)",
    "Previews" : "Pretpregledi",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Besplatno se prijavite na screeenly.com ili postavite vlastiti poslužitelj.",
    "Screeenly API URL" : "URL Screeenly API-ja",
    "Screeenly API key" : "Ključ Screeenly API-ja",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Ključ ScreenshotMachine API-ja",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL Webshot API-ja",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "Spremanje postavki nije uspjelo",
    "Failed to load settings" : "Učitavanje postavki nije uspjelo",
    "This URL is already bookmarked! Overwrite?" : "Ovaj URL je već označen! Prepiši?",
    "Enter bookmark title" : "Unesite naslov knjižne oznake",
    "Enter bookmark URL" : "Unesite URL knjižne oznake",
    "Folder" : "Mapa",
    "Root Folder" : "Korijenska mapa",
    "Save" : "Spremi",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Pristup mreži je onemogućen sukladno zadanim postavkama. Otvorite administratorske postavke aplikacije za knjižne oznake kako biste omogućili dohvaćanje pretpregleda i favicona.",
    "What's new?" : "Što je novog?",
    "Failed to count unavailable bookmarks" : "Brojanje nedostupnih knjižnih oznaka nije uspjelo",
    "Failed to count archived bookmarks" : "Brojanje arhiviranih knjižnih oznaka nije uspjelo",
    "Failed to load bookmark" : "Učitavanje knjižne oznake nije uspjelo",
    "Failed to find existing bookmark" : "Knjižna oznaka nije pronađena",
    "Failed to create bookmark" : "Stvaranje knjižne oznake nije uspjelo",
    "Failed to save bookmark" : "Spremanje knjižne oznake nije uspjelo",
    "Failed to move bookmark" : "Premještanje knjižne oznake nije uspjelo",
    "Failed to copy bookmark" : "Kopiranje knjižne oznake nije uspjelo",
    "Failed to delete bookmark" : "Brisanje knjižne oznake nije uspjelo",
    "Failed to rename tag" : "Preimenovanje oznake nije uspjelo",
    "Failed to load tags" : "Učitavanje oznaka nije uspjelo",
    "Failed to load folders" : "Učitavanje mapa nije uspjelo",
    "Failed to delete folder" : "Brisanje mape nije uspjelo",
    "Failed to create folder" : "Stvaranje mape nije uspjelo",
    "Failed to fetch bookmarks." : "Dohvaćanje knjižnih oznaka nije uspjelo.",
    "Failed to load setting {key}" : "Učitavanje postavke {key} nije uspjelo",
    "Failed to update share {shareId}" : "Ažuriranje dijeljenja {shareId} nije uspjelo",
    "Failed to delete share {shareId}" : "Brisanje dijeljenja {shareId} nije uspjelo",
    "Bookmarks feed" : "Sažetak knjižnih oznaka"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-app-bookmarks-1%3A16.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/hr.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Knjižne oznake",
    "You bookmarked \"%s\"" : "Dodali ste knjižnu oznaku na „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s je dodao knjižnu oznaku na „%2$s“",
    "Someone bookmarked \"%s\"" : "Netko je dodao knjižnu oznaku na „%s“",
    "You deleted \"%s\"" : "Izbrisali ste „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s je izbrisao „%2$s“",
    "Someone deleted \"%s\"" : "Netko je izbrisao „%s“",
    "You created folder \"%s\"" : "Stvorili ste mapu „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s je stvorio mapu „%2$s“",
    "Someone created folder \"%s\"" : "Netko je stvorio mapu „%s“",
    "You moved folder \"%s\"" : "Premjestili ste mapu „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s je premjestio mapu „%2$s“",
    "Someone moved folder \"%s\"" : "Netko je premjestio mapu „%s“",
    "You deleted folder \"%s\"" : "Izbrisali ste mapu „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s je izbrisao mapu „%2$s“",
    "Someone deleted folder \"%s\"" : "Netko je izbrisao mapu „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Dijelite mapu „%1$s“ s „%2$s“",
    "You shared folder \"%s\" with someone" : "Dijelite mapu „%s“ s nekim",
    "%1$s shared folder \"%2$s\" with you" : "%1$s dijeli mapu „%2$s“ s vama",
    "Someone shared folder \"%s\" with you" : "Netko s vama dijeli mapu „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Više ne dijelite mapu „%1$s“ s %2$s",
    "You unshared folder \"%s\" with someone" : "Više ne dijelite mapu „%s“ s nekim",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s više ne dijeli mapu „%2$s“ s vama",
    "Someone unshared folder \"%s\" with you" : "Netko više ne dijeli mapu „%s“ s vama",
    "No file provided for import" : "Nije navedena datoteka za uvoz",
    "Bookmarks shared by %s" : "Knjižne oznake dijeljene s %s",
    "Frequent bookmarks" : "Česte knjižne oznake",
    "Recent bookmarks" : "Nedavne knjižne oznake",
    "Bookmark" : "Dodaj knjižnu oznaku",
    "Bookmark deleted" : "Knjižna oznaka je izbrisana",
    "Bookmark created" : "Knjižna oznaka je stvorena",
    "Bookmark moved" : "Knjižna oznaka je premještena",
    "Bookmark updated" : "Knjižna oznaka je ažurirana",
    "Create bookmark" : "Stvori knjižnu oznaku",
    "Takes a link and adds it to your collection of bookmarks." : "Dodaje poveznicu u zbirku knjižnih oznaka.",
    "Do you really want to delete this bookmark?" : "Želite li zaista izbrisati ovu knjižnu oznaku?",
    "Link copied to clipboard" : "Poveznica je kopirana u međuspremnik",
    "Enter new title" : "Unesi novi naslov",
    "Select bookmark" : "Odaberi knjižnu oznaku",
    "Details" : "Pojedinosti",
    "Rename" : "Preimenuj",
    "Copy link" : "Kopiraj poveznicu",
    "Move" : "Premjesti",
    "Add to folders" : "Dodaj u mape",
    "Content pending" : "Sadržaj na čekanju",
    "This content is being downloaded for offline use. Please check back later." : "Ovaj se sadržaj preuzima radi vanmrežne uporabe. Provjerite kasnije.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke na internetu, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Odabrane mape {folders} i knjižne oznake {bookmarks}",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Odabrana %n knjižna oznaka","Odabrane %n knjižne oznake","Odabrano %n knjižnih oznaka"],
    "_Selected %n folder_::_Selected %n folders_" : ["Odabrana %n mapa","Odabrane %n mape","Odabrano %n mapa"],
    "Do you really want to delete these items?" : "Želite li zaista izbrisati ove stavke?",
    "Open all selected" : "Otvori sve odabrano",
    "Move selection" : "Premjesti odabir",
    "Edit tags of selection" : "Uredi oznake odabira",
    "Delete selection" : "Izbriši odabir",
    "Select all" : "Odaberi sve",
    "Cancel selection" : "Poništi odabir",
    "Sort by created date" : "Razvrstaj prema datumu stvaranja",
    "Sort by last modified" : "Razvrstaj prema posljednjoj izmjeni",
    "Sort by title" : "Razvrstaj prema naslovu",
    "Sort by click count" : "Razvrstaj prema broju klikova",
    "Sort by manual order" : "Razvrstaj prema ručno odabranom redoslijedu",
    "RSS feed copied" : "Sažetak događaja RSS kopiran",
    "Go back" : "Natrag",
    "Share folder" : "Dijeli mapu",
    "Select one or more tags" : "Odaberite jednu ili više oznaka",
    "New" : "Novo",
    "New bookmark" : "Nova knjižna oznaka",
    "New folder" : "Nova mapa",
    "Change to grid view" : "Promijeni u prikaz rešetke",
    "Change to list view" : "Promijeni u prikaz popisa",
    "Copy RSS Feed of current view" : "Kopiraj sažetak događaja RSS trenutnog prikaza",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Sažetak događaja RSS zahtijeva autentifikaciju s pomoću Nextcloudovih vjerodajnica",
    "Search" : "Traži",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Dodavanje %n knjižne oznake u novu mapu","Dodavanje %n knjižne oznake u novu mapu","Dodavanje %n knjižnih oznaka u novu mapu"],
    "Enter a link" : "Unesite poveznicu",
    "Enter a title" : "Unesite naslov",
    "No bookmarks found" : "Nije pronađena nijedna knjižna oznaka",
    "{folders} folders and {bookmarks} bookmarks" : "Mape {folders} i knjižne oznake {bookmarks}",
    "_%n bookmark_::_%n bookmarks_" : ["%n knjižna oznaka","%n knjižne oznake","%n knjižnih oznaka"],
    "_%n folder_::_%n folders_" : ["%n mapa","%n mape","%n mapa"],
    "Add a bookmark" : "Dodaj knjižnu oznaku",
    "Import bookmarks" : "Uvezi knjižne oznake",
    "Sync with your browser" : "Sinkronizirajte s preglednikom",
    "Select folder" : "Odaberi mapu",
    "Enter folder title" : "Unesite naslov mape",
    "Shared by {user}" : "Dijeli {user}",
    "Rename folder" : "Preimenuj mapu",
    "Move folder" : "Premjesti mapu",
    "Choose folder" : "Odaberi mapu",
    "Submit" : "Šalji",
    "Cancel" : "Odustani",
    "Deleting bookmarks" : "Brisanje knjižnih oznaka",
    "Deleting selection" : "Brisanje odabira",
    "Importing bookmarks" : "Uvoz knjižnih oznaka",
    "Moving selection" : "Premještanje odabira",
    "Adding selection to folders" : "Dodavanje odabira u mape",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premještanje %n mape i nekih knjižnih oznaka","Premještanje %n mape i nekih knjižnih oznaka","Premještanje %n mapa i nekih knjižnih oznaka"],
    "_Moving %n folder_::_Moving %n folders_" : ["Premještanje %n mape","Premještanje %n mape","Premještanje %n mapa"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Premještanje %n knjižne oznake","Premještanje %n knjižne oznake","Premještanje %n knjižnih oznaka"],
    "All bookmarks" : "Sve knjižne oznake",
    "Recent" : "Nedavni",
    "Shared with you" : "Podijeljeno s vama",
    "Files" : "Datoteke",
    "Broken links" : "Prekinute poveznice",
    "New tag" : "Nova oznaka",
    "Search tags" : "Oznake pretraživanja",
    "Delete" : "Izbriši",
    "Untagged" : "Uklonjene oznake",
    "{used} bookmarks of {available} available" : "{used} knjižnih oznaka od {available} dostupnih",
    "No bookmarked files" : "Nema datoteka označenih kao knjižne oznake",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
    "No bookmarks here" : "Ovdje nema knjižnih oznaka",
    "Archive path" : "Put arhive",
    "Please select \"Add to home screen\" in your browser menu" : "Odaberite „Dodaj na početni zaslon“ u izborniku preglednika",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Unesite put do mape u aplikaciji Files u kojoj trebaju biti pohranjene datoteke označene kao knjižne oznake.",
    "Client apps" : "Korisnička aplikacija",
    "Also check out the collection of client apps that integrate with this app: " : "Također pregledajte zbirku klijentskih aplikacija koje se mogu integrirati s ovom aplikacijom:",
    "Install web app" : "Instaliraj web aplikaciju",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Ovu aplikaciju možete instalirati na početni zaslon uređaja kako biste mogli brzo pristupiti knjižnim oznakama na telefonu. Ako vam se aplikacija ne sviđa, lako je možete ukloniti s početnog zaslona.",
    "Install on home screen" : "Instaliraj na početni zaslon",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Odvucite na knjižne oznake u svom pregledniku i kliknite kako biste brzo spremili mrežno mjesto u knjižne oznake.",
    "Add to {instanceName}" : "Dodaj u {instanceName}",
    "Need help?" : "Treba li vam pomoć?",
    "Created {time} ago" : "Stvoreno prije {time}",
    "Created on {date}" : "Stvoreno {date}",
    "Title" : "Naslov",
    "Link" : "Poveznica",
    "Untitled folder" : "Mapa bez naslova",
    "Root folder" : "Korijenska mapa",
    "Tags" : "Oznake",
    "Select tags and create new ones" : "Odaberite oznake i stvorite nove",
    "Notes" : "Bilješke",
    "Notes for this bookmark …" : "Bilješke za ovu knjižnu oznaku…",
    "Archived file" : "Arhivirana datoteka",
    "Download file" : "Preuzmi datoteku",
    "Open file location" : "Otvori lokaciju datoteke",
    "Link copied" : "Poveznica je kopirana",
    "Owner" : "Vlasnik",
    "Sharing" : "Dijeljenje",
    "Select a user or group" : "Odaberite korisnika ili grupu",
    "Share link" : "Dijeli poveznicu",
    "Reading allowed" : "Čitanje dopušteno",
    "Copy RSS feed" : "Kopiraj sažetak događaja RSS",
    "Delete link" : "Izbriši poveznicu",
    "Create public link" : "Stvori javnu poveznicu",
    "Resharing allowed" : "Ponovno dijeljenje dopušteno",
    "Editing allowed" : "Uređivanje dopušteno",
    "Allow editing" : "Dopusti uređivanje",
    "Allow resharing" : "Dopusti ponovno dijeljenje",
    "Remove share" : "Ukloni dijeljenje",
    "Failed to save settings" : "Spremanje postavki nije uspjelo",
    "Failed to load settings" : "Učitavanje postavki nije uspjelo",
    "Privacy" : "Privatnost",
    "Enable accessing and collecting information from the web pages you add" : "Omogući pristup i prikupljanje informacija s dodanih mrežnih mjesta",
    "Performance" : "Učinkovitost",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Kod instalacija s većim brojem korisnika može biti korisno ograničiti broj knjižnih oznaka po računu.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Najveći dopušteni broj knjižnih oznaka po računu. (0 znači da nema ograničenja; zadano je bez ograničenja)",
    "Previews" : "Pretpregledi",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Besplatno se prijavite na screeenly.com ili postavite vlastiti poslužitelj.",
    "Screeenly API URL" : "URL Screeenly API-ja",
    "Screeenly API key" : "Ključ Screeenly API-ja",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Ključ ScreenshotMachine API-ja",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL Webshot API-ja",
    "Pageres CLI" : "Pageres CLI",
    "This URL is already bookmarked! Overwrite?" : "Ovaj URL je već označen! Prepiši?",
    "Enter bookmark title" : "Unesite naslov knjižne oznake",
    "Enter bookmark URL" : "Unesite URL knjižne oznake",
    "Folder" : "Mapa",
    "Root Folder" : "Korijenska mapa",
    "Save" : "Spremi",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Pristup mreži je onemogućen sukladno zadanim postavkama. Otvorite administratorske postavke aplikacije za knjižne oznake kako biste omogućili dohvaćanje pretpregleda i favicona.",
    "What's new?" : "Što je novog?",
    "Failed to count unavailable bookmarks" : "Brojanje nedostupnih knjižnih oznaka nije uspjelo",
    "Failed to count archived bookmarks" : "Brojanje arhiviranih knjižnih oznaka nije uspjelo",
    "Failed to load bookmark" : "Učitavanje knjižne oznake nije uspjelo",
    "Failed to find existing bookmark" : "Knjižna oznaka nije pronađena",
    "Failed to create bookmark" : "Stvaranje knjižne oznake nije uspjelo",
    "Failed to save bookmark" : "Spremanje knjižne oznake nije uspjelo",
    "Failed to move bookmark" : "Premještanje knjižne oznake nije uspjelo",
    "Failed to copy bookmark" : "Kopiranje knjižne oznake nije uspjelo",
    "Failed to delete bookmark" : "Brisanje knjižne oznake nije uspjelo",
    "Import successful" : "Uspješan uvoz",
    "Failed to rename tag" : "Preimenovanje oznake nije uspjelo",
    "Failed to load tags" : "Učitavanje oznaka nije uspjelo",
    "Failed to load folders" : "Učitavanje mapa nije uspjelo",
    "Failed to delete folder" : "Brisanje mape nije uspjelo",
    "Failed to create folder" : "Stvaranje mape nije uspjelo",
    "Failed to move parts of selection" : "Premještanje dijelova odabranih stavki nije uspjelo",
    "Failed to delete parts of selection" : "Brisanje dijelova odabranih stavki nije uspjelo",
    "Failed to fetch bookmarks." : "Dohvaćanje knjižnih oznaka nije uspjelo.",
    "Failed to load setting {key}" : "Učitavanje postavke {key} nije uspjelo",
    "Failed to update share {shareId}" : "Ažuriranje dijeljenja {shareId} nije uspjelo",
    "Failed to delete share {shareId}" : "Brisanje dijeljenja {shareId} nije uspjelo",
    "Bookmarks feed" : "Sažetak knjižnih oznaka"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
